DIRESA - distance-regularized Siamese twin autoencoder — DIRESA documentation

# DIRESA - distance-regularized Siamese twin autoencoder

DIRESA is a Python package for dimension reduction based on TensorFlow. The distance-regularized Siamese twin autoencoder architecture is designed to preserve distance (ordering) in latent space while capturing the non-linearities in the datasets.

Introduction

- DIRESA architecture

- Install DIRESA

Tutorial

- Start tutorial

- DIRESA model

- Evaluate

- Convolutional example

- Custom encoder/decoder

Module reference

- models module

- loss module

- callback module

- toolbox module